import numpy as np
import matplotlib.pyplot as plt



colors = ['black', 'lightgray']

def plotTraj(X, U, T=1, filename=None, integrator=None,title=None):

    N = U.shape[1]
    nx = X.shape[0]
    time_vec = np.linspace(0, T, N+1)

    plt.figure()
    plt.subplot(211)
    if integrator is not None:
        for k in range(N):
            X_inter = integrator(X[:,k], U[:,k]).full()
            N_inter = X_inter.shape[1]
            X_inter = np.concatenate((X[:, k][:,None], X_inter), axis=1)
            time_vec_inter = time_vec[k] + np.linspace(0, T/N, N_inter+1)
            plt.plot(time_vec_inter, X_inter[0,:], color=colors[0])
            plt.plot(time_vec_inter, X_inter[1,:], color=colors[1])
    else:
        plt.plot(time_vec, X[0,:])
        plt.plot(time_vec, X[1,:])
    
    plt.plot(time_vec, X[0,:], '.', color=colors[0], label=r'Position $p$')
    plt.plot(time_vec, X[1,:], '.', color=colors[1], label=r'Geschwindigkeit $v$')

    plt.ylim([-2.2, 2.2])
    plt.xlim([0, T])
    plt.legend()
    plt.title(title)
    plt.xticks([])

    plt.subplot(212)
    plt.step(time_vec, np.concatenate((U[0,:], [np.nan]), axis=0), label=r'Steuerung $a$', where='post', color=colors[0])
    plt.legend()
    plt.xlabel(r'Zeit $t$')
    plt.ylim([-2, 2])
    plt.xlim([0, T])

    if filename is not None:
        plt.tight_layout()
        plt.tight_layout(pad=0)
        plt.savefig( filename )